=============================
Resources for ChiantiPy Users
=============================



Forums
======


`The CHIANTI Google group`_

.. _The CHIANTI Google group: https://groups.google.com/forum/#!forum/chianti

Github_

.. _Github:  https://github.com/chianti-atomic/ChiantiPy

